@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-file-style: "bsd" -*-
  * kbnode.c -  keyblock node utility functions
- *        Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+ *        Copyright (C) 1998, 1999, 2000, 2001, 2006 Free Software Foundation, Inc.
  *        Copyright (C) 2002, 2003 Timo Schulz
  *
  * This file is part of OpenCDK.
@@ -65,7 +65,7 @@ _cdk_kbnode_clone( cdk_kbnode_t node )
 
 /**
  * cdk_kbnode_release:
- * @n: the key node
+ * @node: the key node
  *
  * Release the memory of the node.
  **/
@@ -438,7 +438,7 @@ cdk_kbnode_write_to_mem( cdk_kbnode_t node, byte * buf, size_t * r_nbytes )
         if( !buf ) {
             *r_nbytes = len; /* only return the length of the buffer */
             cdk_stream_close( s );
-            return 0;
+            return CDK_Too_Short;
         }
         if( *r_nbytes < len )
             rc = CDK_Too_Short;
@@ -532,7 +532,7 @@ cdk_kbnode_get_attr( cdk_kbnode_t node, int pkttype, int attr )
 /**
  * cdk_kbnode_hash:
  * @node: the key node
- * @hashctx: opaque pointer to the hash context
+ * @md: opaque pointer to the hash context
  * @is_v4: OpenPGP signature (yes=1, no=0)
  * @pkttype: packet type to hash (if zero use the packet type from the node)
  * @flags: flags which depend on the operation
